@@ -186,6 +186,24 @@ class GoogleStyleOptions:
         ),
     ] = True
 
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for parameters, return values, etc.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
@@ -219,12 +237,57 @@ class NumpyStyleOptions:
         ),
     ] = True
 
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for parameters, return values, etc.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
 class SphinxStyleOptions:
     """Sphinx style docstring options."""
 
+    warn_unknown_params: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about documented parameters not appearing in the signature.",
+        ),
+    ] = True
+
+    warn_missing_types: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Warn about missing type/annotation for return values.",
+        ),
+    ] = True
+
+    warnings: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            parent="docstring_options",
+            description="Generally enable/disable warnings when parsing docstrings.",
+        ),
+    ] = True
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
@@ -360,6 +423,15 @@ class SummaryOption:
         ),
     ] = False
 
+    type_aliases: Annotated[
+        bool,
+        _Field(
+            group="members",
+            parent="summary",
+            description="Whether to render summaries of type aliases.",
+        ),
+    ] = False
+
 
 # YORE: EOL 3.9: Replace `**_dataclass_options` with `frozen=True, kw_only=True` within line.
 @dataclass(**_dataclass_options)  # type: ignore[call-overload]
@@ -554,6 +626,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    overloads_only: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Whether to hide the implementation signature if the overloads are shown.",
+        ),
+    ] = False
+
     parameter_headings: Annotated[
         bool,
         _Field(
@@ -614,6 +694,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    show_attribute_values: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Show initial values of attributes in classes.",
+        ),
+    ] = True
+
     show_bases: Annotated[
         bool,
         _Field(
@@ -718,6 +806,22 @@ class PythonInputOptions:
         ),
     ] = True
 
+    show_docstring_type_aliases: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            description="Whether to display the 'Type Aliases' section in the object's docstring.",
+        ),
+    ] = True
+
+    show_docstring_type_parameters: Annotated[
+        bool,
+        _Field(
+            group="docstrings",
+            description="Whether to display the 'Type Parameters' section in the object's docstring.",
+        ),
+    ] = True
+
     show_docstring_warns: Annotated[
         bool,
         _Field(
@@ -809,6 +913,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    show_signature_type_parameters: Annotated[
+        bool,
+        _Field(
+            group="signatures",
+            description="Show the type parameters in generic classes, methods, functions and type aliases signatures.",
+        ),
+    ] = False
+
     show_signature: Annotated[
         bool,
         _Field(
@@ -849,6 +961,14 @@ class PythonInputOptions:
         ),
     ] = False
 
+    skip_local_inventory: Annotated[
+        bool,
+        _Field(
+            group="general",
+            description="Whether to prevent objects from being registered in the local objects inventory.",
+        ),
+    ] = False
+
     signature_crossrefs: Annotated[
         bool,
         _Field(
@@ -873,6 +993,14 @@ class PythonInputOptions:
         ),
     ] = ""
 
+    type_parameter_headings: Annotated[
+        bool,
+        _Field(
+            group="headings",
+            description="Whether to render headings for type parameters (therefore showing type parameters in the ToC).",
+        ),
+    ] = False
+
     unwrap_annotated: Annotated[
         bool,
         _Field(
@@ -914,9 +1042,15 @@ class PythonInputOptions:
         if "summary" in data:
             summary = data["summary"]
             if summary is True:
-                summary = SummaryOption(attributes=True, functions=True, classes=True, modules=True)
+                summary = SummaryOption(attributes=True, functions=True, classes=True, modules=True, type_aliases=True)
             elif summary is False:
-                summary = SummaryOption(attributes=False, functions=False, classes=False, modules=False)
+                summary = SummaryOption(
+                    attributes=False,
+                    functions=False,
+                    classes=False,
+                    modules=False,
+                    type_aliases=False,
+                )
             else:
                 summary = SummaryOption(**summary)
             data["summary"] = summary
@@ -941,7 +1075,7 @@ class PythonOptions(PythonInputOptions):  # type: ignore[override,unused-ignore]
     """A list of filters, or `"public"`."""
 
     summary: SummaryOption = field(default_factory=SummaryOption)
-    """Whether to render summaries of modules, classes, functions (methods) and attributes."""
+    """Whether to render summaries of modules, classes, functions (methods), attributes and type aliases."""
 
     @classmethod
     def coerce(cls, **data: Any) -> MutableMapping[str, Any]:
@@ -1019,7 +1153,9 @@ class PythonInputConfig:
 
     locale: Annotated[
         str | None,
-        _Field(description="The locale to use when translating template strings."),
+        _Field(
+            description="Deprecated. Use mkdocstrings' own `locale` setting instead. The locale to use when translating template strings.",
+        ),
     ] = None
 
     @classmethod
